@@ -10,7 +10,7 @@
     Copyright (c) 2005 Etersoft
     Copyright (c) 2005 Vitaly Lipatov <lav@etersoft.ru>
 
-    $Id: get_charset.c,v 1.16 2005/03/02 18:23:45 lav Exp $
+    $Id: get_charset.c,v 1.19 2005/03/09 20:18:02 lav Exp $
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -51,7 +51,7 @@ static int charset_locale_cmp( const void *name, const void *entry )
 {
     const struct charsetrel_entry *rel = (const struct charsetrel_entry *)entry;
 	DEBUG (printf ("Compare %s with %s\n", (const char*)name, rel->locale));
-    return strcasecmp( (const char *)name, rel->locale );
+    return strcmp( (const char *)name, rel->locale );
 }
 
 /* Removes punctuation characters from charset name */
@@ -61,17 +61,20 @@ char *natspec_humble_charset( const char *charset)
 	char *buf;
 	if (charset == NULL || charset[0] == '\0')
 		return NULL;
-	buf = malloc( strlen(charset) + 1 );
+	/* Do not remove punctuation for ANSI encoding... */
+	if (strstr(charset,"ANSI_X3") != NULL)
+		return strdup(charset);
+	buf = alloca( strlen(charset) + 1 );
    	for (i = 0, j = 0; charset[i]; i++)
 	{
 		if (charset[i] == ':')
 			break;
-        if (isalnum(charset[i]))
-			buf[j++] = toupper(charset[i]);
+        if (_n_isalnum(charset[i]))
+			buf[j++] = _n_toupper(charset[i]);
 	}
    	buf[j] = 0;
 	DEBUG (printf ("Clean charset '%s', after: '%s'",charset, buf));
-	return buf;
+	return strdup(buf);
 }
 
 /* Returns current charset */
@@ -132,7 +135,7 @@ static const struct charsetrel_entry* get_entry_by_charset(const int bytype,
 {
 	const struct charsetrel_entry *entry = NULL;
 	char *must_free = NULL;
-	DEBUG (printf("get_entry_by_charset charset=%s, locale=%s\n",charset, locale));
+	DEBUG (printf("get_entry_by_charset charset=%s\n",charset));
 	/* If charset is NULL, use current charset */
 	if ((charset == NULL || charset[0] == '\0') && bytype == NATSPEC_UNIXCS)
 	{
@@ -146,7 +149,7 @@ static const struct charsetrel_entry* get_entry_by_charset(const int bytype,
 		DEBUG (printf("Find with charset '%s'\n", charset));
 		/* Fixme: can we strict suppose enemy encoding by unix charset? */
 		for (i = 0; i< sizeof(charset_relation)/sizeof(charset_relation[0]); i++)
-			if (!strcasecmp (charset, get_cs_by_type(bytype,&charset_relation[i])))
+			if (!strcmp (charset, get_cs_by_type(bytype,&charset_relation[i])))
 			{
 	    		entry = &charset_relation[i];
 				break;
@@ -162,14 +165,14 @@ static const struct charsetrel_entry* get_entry_by_locale(const char *locale)
 	const struct charsetrel_entry *entry = NULL;
 	char *replocale = _natspec_repack_locale(locale);
 
-	/* Search the same locale string in table */
+	/* Search the same locale string in table. We are sure locale is repacked (normalized) */
 	if (replocale != NULL && replocale[0] != '\0')
 		entry = bsearch( replocale, charset_relation,
 	    	sizeof(charset_relation)/sizeof(charset_relation[0]),
 	        sizeof(charset_relation[0]), charset_locale_cmp );
 	free (replocale);
 
-	DEBUG (if (!entry) printf ("Can't find the locale '%s', search by charset '%s' now\n", locale, charset));
+	DEBUG (if (!entry) printf ("Can't find the locale '%s'\n", locale));
 	return entry;
 }
 
@@ -184,7 +187,7 @@ const char * natspec_get_charset_by_locale(const int type, const char *locale)
 		locale = must_free = natspec_get_system_locale();
 	else
 	if (locale[0] == '\0')
-		locale = must_free = natspec_get_user_locale();
+		locale = must_free = natspec_get_current_locale();
 	entry = get_entry_by_locale(locale);
 	free (must_free);
 	return get_cs_by_type(type, entry);
