@@ -12,7 +12,7 @@
     Copyright (c) 2005 Etersoft
     Copyright (c) 2005 Vitaly Lipatov <lav@etersoft.ru>
 
-    $Id: get_locale.c,v 1.13 2005/03/02 18:24:24 lav Exp $
+    $Id: get_locale.c,v 1.16 2005/03/17 15:35:18 lav Exp $
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -64,9 +64,9 @@ static char *get_from_env()
 }
 
 /* Returns user locale string (malloc allocated)
- * FIXME: can we do it with glibc?
+ * FIXME: can we do it with glibc not my get_from_env?
  */
-char *natspec_get_user_locale()
+char *natspec_get_current_locale()
 {
 	char *locale = get_from_env();
 	if (!locale)
@@ -74,6 +74,11 @@ char *natspec_get_user_locale()
 	return locale;
 }
 
+char *natspec_get_user_locale()
+{
+	return natspec_get_current_locale();
+}
+
 /*
 const char *get_i18n_filename()
 {
@@ -179,8 +184,7 @@ char *_natspec_repack_locale(const char *locale)
 {
 	int i;
 	char *buf, *lang, *next, *dialect, *charset, *country;
-    if (!locale || !locale[0] ||
-		!strcmp(locale,"POSIX") || !strcmp(locale,"C") )
+    if (!locale || !locale[0])
 		return NULL;
 	DEBUG (printf("repack_locale\n"));
 	lang = strdup( locale );
@@ -191,12 +195,12 @@ char *_natspec_repack_locale(const char *locale)
     country = strchr(lang,'_'); if (country) *country++ = '\0';
 
 	for (i=0; i<strlen(lang); i++)
-		tolower(lang[i]);
+		_n_tolower(lang[i]);
 	strcpy(buf, lang);
 	if (country)
 	{
 		for (i=0; i<strlen(country); i++)
-			toupper(country[i]);
+			_n_toupper(country[i]);
 		strcat(buf, "_");
 		strcat(buf, country);
 	}
@@ -209,6 +213,8 @@ char *_natspec_repack_locale(const char *locale)
 	}
 	if (dialect)
 	{
+		for(i=0; i<strlen(dialect); i++)
+			_n_tolower(dialect[i]);
 		strcat(buf, "@");
 		strcat(buf, dialect);
 	}
